=======================
The ``getlino`` package
=======================




``getlino`` is a command-line tool for installing Lino in different environments.

Note: If you **just want to install** Lino, then this documentation tree is
**not for you**. You want to read the `Hosting Guide
<https://hosting.lino-framework.org/>`__  or the `Developer Guide
<https://dev.lino-framework.org/>`__ instead. This documentation tree is for
people who want to help with developing the tool that you use to install Lino.

- Project homepage: https://gitlab.com/lino-framework/getlino
- Documentation:
  https://getlino.lino-framework.org/
  (mirrored at https://lino-framework.gitlab.io/getlino/)

    
